ipecharts package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ipecharts.option

Submodules
----------

ipecharts.basewidget module
---------------------------

.. automodule:: ipecharts.basewidget
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.echarts module
------------------------

.. automodule:: ipecharts.echarts
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ipecharts
   :members:
   :undoc-members:
   :show-inheritance:
